==> haskell-monad-unlift-0.2.0-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-unlift.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-unlift
version:              0.2.0
visibility:           public
id:                   monad-unlift-0.2.0-95213IiwRTGCpJGFLWy3oe
key:                  monad-unlift-0.2.0-95213IiwRTGCpJGFLWy3oe
license:              MIT
copyright:            FP Complete
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/monad-unlift
synopsis:             Typeclasses for representing monad transformer unlifting
description:          See README.md
category:             Control
abi:                  9446e98b2109f8de6576f17443ee99d8
exposed:              True
exposed-modules:      Control.Monad.Trans.Unlift
import-dirs:          /usr/lib/ghc-8.8.1/site-local/monad-unlift-0.2.0
library-dirs:         /usr/lib/ghc-8.8.1/site-local/monad-unlift-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/monad-unlift-0.2.0
hs-libraries:         HSmonad-unlift-0.2.0-95213IiwRTGCpJGFLWy3oe
depends:
    base-4.13.0.0 constraints-0.11.2-1RboJ4HmRnW3qCgKIBM0as
    monad-control-1.0.2.3-2T4cwChuHaf2J1ZNL7027K transformers-0.5.6.2
    transformers-base-0.4.5.2-FzngjrlKxWZ13jyOckRvK9

haddock-interfaces:
    /usr/share/doc/haskell-monad-unlift/html/monad-unlift.haddock

haddock-html:         /usr/share/doc/haskell-monad-unlift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-unlift-0.2.0-83-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-unlift.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-unlift
version:              0.2.0
visibility:           public
id:                   monad-unlift-0.2.0-6wLKQMHVI0S1YuLXXpbuNk
key:                  monad-unlift-0.2.0-6wLKQMHVI0S1YuLXXpbuNk
license:              MIT
copyright:            FP Complete
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/monad-unlift
synopsis:             Typeclasses for representing monad transformer unlifting
description:          See README.md
category:             Control
abi:                  9ec4f44c5c7ea01265915d3aabb2d579
exposed:              True
exposed-modules:      Control.Monad.Trans.Unlift
import-dirs:          /usr/lib/ghc-8.8.1/site-local/monad-unlift-0.2.0
library-dirs:         /usr/lib/ghc-8.8.1/site-local/monad-unlift-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/monad-unlift-0.2.0
hs-libraries:         HSmonad-unlift-0.2.0-6wLKQMHVI0S1YuLXXpbuNk
depends:
    base-4.13.0.0 constraints-0.11.2-FCDiakLjZNJ8iotxyKauIh
    monad-control-1.0.2.3-AW09c0LCfgFAiXuZpIkqPT transformers-0.5.6.2
    transformers-base-0.4.5.2-CRR82WNUNTp82PAV0y2ybQ

haddock-interfaces:
    /usr/share/doc/haskell-monad-unlift/html/monad-unlift.haddock

haddock-html:         /usr/share/doc/haskell-monad-unlift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
